==> qtjambi-webenginewidgets-5.15.9-sources.jar: io/qt/webengine/widgets/QWebEngineScript.java <==
package io.qt.webengine.widgets;


/**
 * <p>Encapsulates a JavaScript program</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qwebenginescript.html">QWebEngineScript</a></p>
 */
public class QWebEngineScript extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::InjectionPoint</a></p>
     */
    public enum InjectionPoint implements io.qt.QtEnumerator {
        Deferred(0),
        DocumentReady(1),
        DocumentCreation(2);

        private InjectionPoint(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static InjectionPoint resolve(int value) {
            switch (value) {
            case 0: return Deferred;
            case 1: return DocumentReady;
            case 2: return DocumentCreation;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::ScriptWorldId</a></p>
     */
    public enum ScriptWorldId implements io.qt.QtEnumerator {
        MainWorld(0),
        ApplicationWorld(1),
        UserWorld(2);

        private ScriptWorldId(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static ScriptWorldId resolve(int value) {
            switch (value) {
            case 0: return MainWorld;
            case 1: return ApplicationWorld;
            case 2: return UserWorld;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public QWebEngineScript(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineScript instance);
    
    public QWebEngineScript(io.qt.webengine.widgets.QWebEngineScript other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineScript instance, io.qt.webengine.widgets.QWebEngineScript other);
    
    @io.qt.QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineScript.InjectionPoint injectionPoint(){
        return io.qt.webengine.widgets.QWebEngineScript.InjectionPoint.resolve(injectionPoint_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int injectionPoint_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void set(io.qt.webengine.widgets.QWebEngineScript other){
        set_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebEngineScript(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.QWebEngineScript other){
        return operator_equal_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineScript_constfct(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final boolean runsOnSubFrames(){
        return runsOnSubFrames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean runsOnSubFrames_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setInjectionPoint(io.qt.webengine.widgets.QWebEngineScript.InjectionPoint arg__1){
        setInjectionPoint_native_QWebEngineScript_InjectionPoint(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1.value());
    }
    
    @io.qt.QtUninvokable
    private native void setInjectionPoint_native_QWebEngineScript_InjectionPoint(long __this__nativeId, int arg__1);
    
    @io.qt.QtUninvokable
    public final void setName(java.lang.String arg__1){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @io.qt.QtUninvokable
    public final void setRunsOnSubFrames(boolean on){
        setRunsOnSubFrames_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), on);
    }
    
    @io.qt.QtUninvokable
    private native void setRunsOnSubFrames_native_bool(long __this__nativeId, boolean on);
    
    @io.qt.QtUninvokable
    public final void setSourceCode(java.lang.String arg__1){
        setSourceCode_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setSourceCode_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @io.qt.QtUninvokable
    public final void setWorldId(int arg__1){
        setWorldId_native_unsigned_int(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setWorldId_native_unsigned_int(long __this__nativeId, int arg__1);
    
    @io.qt.QtUninvokable
    public final java.lang.String sourceCode(){
        return sourceCode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String sourceCode_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void swap(io.qt.webengine.widgets.QWebEngineScript other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QWebEngineScript(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final int worldId(){
        return worldId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int worldId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineScript(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineScript) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineScript) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    @Override
    public QWebEngineScript clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineScript clone_native(long __this_nativeId);
}

==> qtjambi-webenginewidgets-5.15.10-sources.jar: io/qt/webengine/widgets/QWebEngineScript.java <==
package io.qt.webengine.widgets;


/**
 * <p>Encapsulates a JavaScript program</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebenginescript.html">QWebEngineScript</a></p>
 */
public class QWebEngineScript extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::InjectionPoint</a></p>
     */
    public enum InjectionPoint implements io.qt.QtEnumerator {
        Deferred(0),
        DocumentReady(1),
        DocumentCreation(2);

        private InjectionPoint(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static InjectionPoint resolve(int value) {
            switch (value) {
            case 0: return Deferred;
            case 1: return DocumentReady;
            case 2: return DocumentCreation;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::ScriptWorldId</a></p>
     */
    public enum ScriptWorldId implements io.qt.QtEnumerator {
        MainWorld(0),
        ApplicationWorld(1),
        UserWorld(2);

        private ScriptWorldId(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static ScriptWorldId resolve(int value) {
            switch (value) {
            case 0: return MainWorld;
            case 1: return ApplicationWorld;
            case 2: return UserWorld;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public QWebEngineScript(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineScript instance);
    
    public QWebEngineScript(io.qt.webengine.widgets.QWebEngineScript other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineScript instance, io.qt.webengine.widgets.QWebEngineScript other);
    
    @io.qt.QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineScript.InjectionPoint injectionPoint(){
        return io.qt.webengine.widgets.QWebEngineScript.InjectionPoint.resolve(injectionPoint_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int injectionPoint_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void set(io.qt.webengine.widgets.QWebEngineScript other){
        set_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebEngineScript(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.QWebEngineScript other){
        return operator_equal_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineScript_constfct(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final boolean runsOnSubFrames(){
        return runsOnSubFrames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean runsOnSubFrames_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setInjectionPoint(io.qt.webengine.widgets.QWebEngineScript.InjectionPoint arg__1){
        setInjectionPoint_native_QWebEngineScript_InjectionPoint(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1.value());
    }
    
    @io.qt.QtUninvokable
    private native void setInjectionPoint_native_QWebEngineScript_InjectionPoint(long __this__nativeId, int arg__1);
    
    @io.qt.QtUninvokable
    public final void setName(java.lang.String arg__1){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @io.qt.QtUninvokable
    public final void setRunsOnSubFrames(boolean on){
        setRunsOnSubFrames_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), on);
    }
    
    @io.qt.QtUninvokable
    private native void setRunsOnSubFrames_native_bool(long __this__nativeId, boolean on);
    
    @io.qt.QtUninvokable
    public final void setSourceCode(java.lang.String arg__1){
        setSourceCode_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setSourceCode_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @io.qt.QtUninvokable
    public final void setWorldId(int arg__1){
        setWorldId_native_unsigned_int(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setWorldId_native_unsigned_int(long __this__nativeId, int arg__1);
    
    @io.qt.QtUninvokable
    public final java.lang.String sourceCode(){
        return sourceCode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String sourceCode_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void swap(io.qt.webengine.widgets.QWebEngineScript other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QWebEngineScript(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final int worldId(){
        return worldId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int worldId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineScript(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineScript) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineScript) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    @Override
    public QWebEngineScript clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineScript clone_native(long __this_nativeId);
}
